Learn R Programming

poweRlaw (version 0.20.1)

bootstrap_p: Estimates the lower bound (xmin)

Description

When fitting heavy tailed distributions, sometimes it is necessary to estimate the lower threshold, xmin. The lower bound is estimated by calculating the minimising the Kolmogorov-Smirnoff statistic (as described in Clauset, Shalizi, Newman (2009)). [object Object],[object Object],[object Object],[object Object]

Usage

bootstrap_p(m, xmins = NULL, pars = NULL,
    no_of_sims = 100, threads = 1, data_max = 1e+05)

bootstrap(m, xmins = NULL, pars = NULL, no_of_sims = 100, threads = 1, data_max = 1e+05)

get_KS_statistic(m)

estimate_xmin(m, xmins = NULL, pars = NULL, data_max = 1e+05)

Arguments

Examples

Run this code
###################################################
# Load the data set and create distribution object#
###################################################
x = 1:10
m = displ$new(x)

###################################################
# Estimate xmin and pars                          #
###################################################
est = estimate_xmin(m)
m$setXmin(est)

###################################################
# Bootstrap examples                              #
###################################################
bootstrap(m, no_of_sims=1, threads=1)
bootstrap_p(m, no_of_sims=1, threads=1)

Run the code above in your browser using DataLab