Learn R Programming

poweRlaw (version 0.60.3)

dist_all_cdf: The data cumulative distribution function

Description

This is generic function for distribution objects. This function calculates the data or empirical cdf.

The functions dist_data_all_cdf and dist_all_cdf are only available for discrete distributions. Theremain purpose is to optimise the bootstrap procedure, where generating a vector xmin:xmax is very quick. Also, when bootstrapping very large values can be generated.

Usage

dist_all_cdf(m, lower_tail = TRUE, xmax = 1e+05)
dist_data_cdf(m, lower_tail = TRUE, xmax = 1e+05)
dist_data_all_cdf(m, lower_tail = TRUE, xmax = 1e+05)
"dist_data_cdf"(m, lower_tail = TRUE, xmax = 1e+05)
"dist_data_all_cdf"(m, lower_tail = TRUE, xmax = 1e+05)
"dist_data_cdf"(m, lower_tail = TRUE, xmax = 1e+05)

Arguments

m
a distribution object.
lower_tail
logical; if TRUE (default), probabilities are $P[X \le x]$, otherwise, $P[X > x]$.
xmax
default 1e5. The maximum x value calculated when working out the CDF.

Examples

Run this code
##########################################
#Load data and create distribution object#
##########################################
data(moby_sample)
m = displ$new(moby_sample)
m$setXmin(7);m$setPars(2)

##########################################
# The data cdf                           #
##########################################
dist_data_cdf(m)

Run the code above in your browser using DataLab