Rdocumentation
powered by
Learn R Programming
poweRlaw (version 0.60.3)
get_KS_statistic: Deprecated function
Description
This function is now deprecated and may be removed in future versions.
Usage
get_KS_statistic(m, xmax = 1e+05, distance = "ks")
Arguments
m
A reference class object that contains the data.
xmax
default
1e5
. The maximum x value calculated when working out the CDF. See details for further information.
distance
A string containing the distance measure (or measures) to calculate. Possible values are
ks
or
reweight
. See details for further information.
See Also
get_distance_statistic