Learn R Programming

poweRlaw (version 0.60.3)

lines,distribution-method: Generic plotting functions

Description

These are generic functions for distribution reference objects. Standard plotting functions, i.e. plot, points, and lines work with all distribution objects.

Usage

"lines"(x, cut = FALSE, draw = TRUE, length.out = 100, ...)
"plot"(x, cut = FALSE, draw = TRUE, ...)
"points"(x, cut = FALSE, draw = TRUE, length.out = 100, ...)

Arguments

x
a distribution reference object.
cut
logical (default FALSE) - Where should the plot begin. If cut=FALSE, then the plot will start at the minimum data value. Otherwise, the plot will start from xmin
draw
logical (default TRUE). Should the plot/lines/points function plot or return the data (in a data frame object).
length.out
numeric, default 100. How many points should the distribution be evaulated at. This argument is only for plotting the fitted lines.
...
Further arguments passed to the lines functions.