Learn R Programming

poweRlaw (version 0.20.2)

native_american: Casualities in the American Indian Wars (1776 and 1890)

Description

These data files contain the observed casualties in the American Indian Wars. The data sets native_american and us_american contain the casualties on the Native American and US American sides respectively. Each data set is a data frame, with two columns: the number of casualities and the conflict date.

Arguments

docType

data

format

Data frame

source

Friedman, Jeffrey A. "Using Power Laws to Estimate Conflict Size." (2013).