bootstrap function. [object Object],[object Object] The
bootstrap_moby values correspond to the first row
of table 6.1 in the Clauset et al paper: [object Object],[object Object] The bootstrap_p_moby gives the p-value for the
hypothesis test of whether the data follows a power-law.
For this simulation study, we get a value of 0.43 (the
paper gives 0.49).
moby, bootstrap, bootstrap_p