poweRlaw-package: The poweRlaw package
Description
The poweRlaw package aims to make fitting power laws and other heavy-tailed distributions
straightforward. This package contains R functions for fitting, comparing and visualising heavy
tailed distributions. Overall, it provides a principaled approach to fitting power laws to data.
References
A. Clauset, C.R. Shalizi, and M.E.J. Newman,
"Power-law distributions in empirical data" SIAM Review 51(4), 661-703 (2009).